==> vala-0.3.4.tar.bz2: vala-0.3.4/vala/valadestructor.c <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valadestructor.h>
#include <vala/valablock.h>
#include <vala/valaformalparameter.h>
#include <vala/valasourcereference.h>
#include <vala/valacodevisitor.h>




struct _ValaDestructorPrivate {
	ValaBlock* _body;
	ValaFormalParameter* _this_parameter;
	MemberBinding _binding;
};

#define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
enum  {
	VALA_DESTRUCTOR_DUMMY_PROPERTY,
	VALA_DESTRUCTOR_BODY,
	VALA_DESTRUCTOR_THIS_PARAMETER,
	VALA_DESTRUCTOR_BINDING
};
static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_destructor_parent_class = NULL;
static void vala_destructor_dispose (GObject * obj);



/**
 * Creates a new destructor.
 *
 * @param source_reference reference to source code
 * @return                 newly created destructor
 */
ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
	ValaDestructor * self;
	g_return_val_if_fail (source_reference == NULL || VALA_IS_SOURCE_REFERENCE (source_reference), NULL);
	self = g_object_newv (VALA_TYPE_DESTRUCTOR, 0, NULL);
	vala_code_node_set_source_reference (VALA_CODE_NODE (self), source_reference);
	return self;
}


static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	vala_code_visitor_visit_destructor (visitor, self);
}


static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (base);
	g_return_if_fail (VALA_IS_CODE_VISITOR (visitor));
	if (self->priv->_body != NULL) {
		vala_code_node_accept (VALA_CODE_NODE (self->priv->_body), visitor);
	}
}


ValaBlock* vala_destructor_get_body (ValaDestructor* self) {
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
	return self->priv->_body;
}


void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
	ValaBlock* _tmp2;
	ValaBlock* _tmp1;
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL))), _tmp2);
}


ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self) {
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), NULL);
	return self->priv->_this_parameter;
}


void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value) {
	ValaFormalParameter* _tmp2;
	ValaFormalParameter* _tmp1;
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : g_object_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL))), _tmp2);
}


MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
	g_return_val_if_fail (VALA_IS_DESTRUCTOR (self), 0);
	return self->priv->_binding;
}


void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value) {
	g_return_if_fail (VALA_IS_DESTRUCTOR (self));
	self->priv->_binding = value;
}


static void vala_destructor_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		g_value_set_object (value, vala_destructor_get_body (self));
		break;
		case VALA_DESTRUCTOR_THIS_PARAMETER:
		g_value_set_object (value, vala_destructor_get_this_parameter (self));
		break;
		case VALA_DESTRUCTOR_BINDING:
		g_value_set_enum (value, vala_destructor_get_binding (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_destructor_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (object);
	switch (property_id) {
		case VALA_DESTRUCTOR_BODY:
		vala_destructor_set_body (self, g_value_get_object (value));
		break;
		case VALA_DESTRUCTOR_THIS_PARAMETER:
		vala_destructor_set_this_parameter (self, g_value_get_object (value));
		break;
		case VALA_DESTRUCTOR_BINDING:
		vala_destructor_set_binding (self, g_value_get_enum (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void vala_destructor_class_init (ValaDestructorClass * klass) {
	vala_destructor_parent_class = g_type_class_peek_parent (klass);
	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
	G_OBJECT_CLASS (klass)->get_property = vala_destructor_get_property;
	G_OBJECT_CLASS (klass)->set_property = vala_destructor_set_property;
	G_OBJECT_CLASS (klass)->dispose = vala_destructor_dispose;
	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BODY, g_param_spec_object ("body", "body", "body", VALA_TYPE_BLOCK, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_THIS_PARAMETER, g_param_spec_object ("this-parameter", "this-parameter", "this-parameter", VALA_TYPE_FORMAL_PARAMETER, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), VALA_DESTRUCTOR_BINDING, g_param_spec_enum ("binding", "binding", "binding", TYPE_MEMBER_BINDING, MEMBER_BINDING_INSTANCE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void vala_destructor_instance_init (ValaDestructor * self) {
	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
	self->priv->_binding = MEMBER_BINDING_INSTANCE;
}


static void vala_destructor_dispose (GObject * obj) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (g_object_unref (self->priv->_body), NULL)));
	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (g_object_unref (self->priv->_this_parameter), NULL)));
	G_OBJECT_CLASS (vala_destructor_parent_class)->dispose (obj);
}


GType vala_destructor_get_type (void) {
	static GType vala_destructor_type_id = 0;
	if (G_UNLIKELY (vala_destructor_type_id == 0)) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_instance_init };
		vala_destructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDestructor", &g_define_type_info, 0);
	}
	return vala_destructor_type_id;
}

==> vala-0.5.1.tar.bz2: vala-0.5.1/vala/valadestructor.c <==
/* valadestructor.vala
 *
 * Copyright (C) 2006-2008  Jürg Billeter
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.

 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 *
 * Author:
 * 	Jürg Billeter <j@bitron.ch>
 */

#include <vala/valadestructor.h>
#include <stdlib.h>
#include <string.h>
#include <vala/valaformalparameter.h>
#include <vala/valacodevisitor.h>
#include <vala/valablock.h>
#include <vala/valasourcereference.h>




struct _ValaDestructorPrivate {
	ValaBlock* _body;
	ValaFormalParameter* _this_parameter;
	MemberBinding _binding;
};

#define VALA_DESTRUCTOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_DESTRUCTOR, ValaDestructorPrivate))
enum  {
	VALA_DESTRUCTOR_DUMMY_PROPERTY
};
static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor);
static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor);
static gpointer vala_destructor_parent_class = NULL;
static void vala_destructor_finalize (ValaCodeNode* obj);



/**
 * Creates a new destructor.
 *
 * @param source_reference reference to source code
 * @return                 newly created destructor
 */
ValaDestructor* vala_destructor_construct (GType object_type, ValaSourceReference* source_reference) {
	ValaDestructor* self;
	self = ((ValaDestructor*) (g_type_create_instance (object_type)));
	self = ((ValaDestructor*) (vala_symbol_construct (object_type, NULL, source_reference)));
	return self;
}


ValaDestructor* vala_destructor_new (ValaSourceReference* source_reference) {
	return vala_destructor_construct (VALA_TYPE_DESTRUCTOR, source_reference);
}


static void vala_destructor_real_accept (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaDestructor * self;
	self = ((ValaDestructor*) (base));
	g_return_if_fail (visitor != NULL);
	vala_code_visitor_visit_destructor (visitor, self);
}


static void vala_destructor_real_accept_children (ValaCodeNode* base, ValaCodeVisitor* visitor) {
	ValaDestructor * self;
	self = ((ValaDestructor*) (base));
	g_return_if_fail (visitor != NULL);
	if (self->priv->_body != NULL) {
		vala_code_node_accept (((ValaCodeNode*) (self->priv->_body)), visitor);
	}
}


ValaBlock* vala_destructor_get_body (ValaDestructor* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_body;
}


void vala_destructor_set_body (ValaDestructor* self, ValaBlock* value) {
	ValaBlock* _tmp2;
	ValaBlock* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_body = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL))), _tmp2);
}


ValaFormalParameter* vala_destructor_get_this_parameter (ValaDestructor* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return self->priv->_this_parameter;
}


void vala_destructor_set_this_parameter (ValaDestructor* self, ValaFormalParameter* value) {
	ValaFormalParameter* _tmp2;
	ValaFormalParameter* _tmp1;
	g_return_if_fail (self != NULL);
	_tmp2 = NULL;
	_tmp1 = NULL;
	self->priv->_this_parameter = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL ? NULL : vala_code_node_ref (_tmp1))), (self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL))), _tmp2);
}


MemberBinding vala_destructor_get_binding (ValaDestructor* self) {
	g_return_val_if_fail (self != NULL, 0);
	return self->priv->_binding;
}


void vala_destructor_set_binding (ValaDestructor* self, MemberBinding value) {
	g_return_if_fail (self != NULL);
	self->priv->_binding = value;
}


static void vala_destructor_class_init (ValaDestructorClass * klass) {
	vala_destructor_parent_class = g_type_class_peek_parent (klass);
	VALA_CODE_NODE_CLASS (klass)->finalize = vala_destructor_finalize;
	g_type_class_add_private (klass, sizeof (ValaDestructorPrivate));
	VALA_CODE_NODE_CLASS (klass)->accept = vala_destructor_real_accept;
	VALA_CODE_NODE_CLASS (klass)->accept_children = vala_destructor_real_accept_children;
}


static void vala_destructor_instance_init (ValaDestructor * self) {
	self->priv = VALA_DESTRUCTOR_GET_PRIVATE (self);
	self->priv->_binding = MEMBER_BINDING_INSTANCE;
}


static void vala_destructor_finalize (ValaCodeNode* obj) {
	ValaDestructor * self;
	self = VALA_DESTRUCTOR (obj);
	(self->priv->_body == NULL ? NULL : (self->priv->_body = (vala_code_node_unref (self->priv->_body), NULL)));
	(self->priv->_this_parameter == NULL ? NULL : (self->priv->_this_parameter = (vala_code_node_unref (self->priv->_this_parameter), NULL)));
	VALA_CODE_NODE_CLASS (vala_destructor_parent_class)->finalize (obj);
}


GType vala_destructor_get_type (void) {
	static GType vala_destructor_type_id = 0;
	if (vala_destructor_type_id == 0) {
		static const GTypeInfo g_define_type_info = { sizeof (ValaDestructorClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) vala_destructor_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (ValaDestructor), 0, (GInstanceInitFunc) vala_destructor_instance_init, NULL };
		vala_destructor_type_id = g_type_register_static (VALA_TYPE_SYMBOL, "ValaDestructor", &g_define_type_info, 0);
	}
	return vala_destructor_type_id;
}
